@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 use MooseX::Types::Moose qw( Str Maybe HashRef );
 
-our $VERSION = '1.090_102';
+our $VERSION = '1.101_001';
 $VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
 
 with 'Perl::Dist::WiX::Role::Asset';
@@ -94,7 +94,7 @@ sub install {
 	# Copy in licenses
 	my $licenses = $self->_get_license();
 	if ( defined $licenses ) {
-		my $license_dir = catdir( $self->image_dir, 'licenses' );
+		my $license_dir = $self->_dir('licenses');
 		push @files,
 		  $self->_extract_filemap( $tgz, $licenses, $license_dir, 1 );
 	}
@@ -180,26 +180,32 @@ This class inherits from L<Perl::Dist::WiX::Role::Asset> and shares its API.
 
 =head2 new
 
-TO BE COMPLETED
+TODO: TO BE COMPLETED
+
+=head2 install
+
+Installs the library specified by this object. 
 
 =head1 SUPPORT
 
 Bugs should be reported via the CPAN bug tracker at
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Dist>
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Dist-WiX>
 
 For other issues, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Perl::Dist>, L<Perl::Dist::Inno>, L<Perl::Dist::Asset>
+L<Perl::Dist::WiX>, L<Perl::Dist::WiX::Role::Asset>
 
 =head1 COPYRIGHT
 
+Copyright 2009 Curtis Jewell.
+
 Copyright 2007 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
