@@ -24,40 +24,24 @@ build Perl itself.
 =cut
 
 use 5.008001;
-use strict;
-use warnings;
-use Archive::Zip qw( :ERROR_CODES            );
-use English qw( -no_match_vars          );
-use List::MoreUtils qw( any none                );
+use Moose;
+use English qw( -no_match_vars );
+use List::MoreUtils qw( any );
 use Params::Util qw( _HASH _STRING _INSTANCE );
-use Readonly qw( Readonly                );
+use Readonly qw( Readonly );
 use Storable qw( retrieve );
 use File::Spec::Functions qw(
   catdir catfile catpath tmpdir splitpath rel2abs curdir
 );
-use Archive::Tar 1.42 qw();
 use Module::CoreList 2.18 qw();
-require File::Remove;
-require File::pushd;
-require File::ShareDir;
-require File::Copy::Recursive;
-require File::PathList;
-require HTTP::Status;
-require IO::String;
-require IO::Handle;
-require LWP::UserAgent;
-require LWP::Online;
-require PAR::Dist;
-require Probe::Perl;
-require SelectSaver;
-require Template;
-require Win32;
+
+# require IO::Handle;
 require Perl::Dist::WiX::Asset::Perl;
 require Perl::Dist::WiX::Toolchain;
 require File::List::Object;
 
-our $VERSION = '1.090_103';
-$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+our $VERSION = '1.101_001';
+$VERSION =~ s/_//sm;
 
 Readonly my %CORE_MODULE_FIX => (
 	'IO::Compress'        => 'IO::Compress::Base',
@@ -127,9 +111,9 @@ the default tasklist after the "perl toolchain" is installed.
 
 =cut
 
-sub install_cpan_upgrades {
+sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 	my $self = shift;
-	unless ( $self->bin_perl ) {
+	unless ( $self->bin_perl() ) {
 		PDWiX->throw(
 			'Cannot install CPAN modules yet, perl is not installed');
 	}
@@ -170,8 +154,8 @@ sub install_cpan_upgrades {
 			next MODULE;
 		}
 
-		if (    ( $module->cpan_file =~ m{/Module-Install-\d}msx )
-			and ( $module->cpan_version > 0.79 ) )
+		if (    ( $module->cpan_file() =~ m{/Module-Install-\d}msx )
+			and ( $module->cpan_version() > 0.79 ) )
 		{
 
 			# We need a few more modules.
@@ -224,8 +208,7 @@ sub install_cpan_upgrades {
 	# Yes, I know that technically it's a core module with
 	# non-core dependencies, and that's ugly. I've just got
 	# to live with it.
-	my $autodie_location =
-	  catfile( $self->image_dir, qw(perl lib autodie.pm) );
+	my $autodie_location = $self->_file(qw(perl lib autodie.pm));
 
 	if ( -e $autodie_location ) {
 		$self->install_modules(qw( Win32::Process IPC::System::Simple ));
@@ -233,15 +216,35 @@ sub install_cpan_upgrades {
 
 	# Getting CPANPLUS config file installed if required.
 	my $cpanp_config_location =
-	  catfile( $self->image_dir, qw(perl lib CPANPLUS Config.pm) );
+	  $self->_file(qw(perl lib CPANPLUS Config.pm));
 
 	if ( -e $cpanp_config_location ) {
+
+		# Installing 0.89_02 because of accumulated fixes,
+		# including one in which the config set
+		# by us works better.
+		$self->install_distribution(
+			name             => 'BINGOS/CPANPLUS-0.89_02.tar.gz',
+			mod_name         => 'CPANPLUS',
+			makefilepl_param => ['INSTALLDIRS=perl'],
+			buildpl_param    => [ '--installdirs', 'core' ],
+		);
+
 		$self->trace_line( 1,
 			"Getting CPANPLUS config file ready for patching\n" );
 
 		$self->patch_file(
-			'perl/lib/CPANPLUS/Config.pm' => $self->image_dir,
+			'perl/lib/CPANPLUS/Config.pm' => $self->image_dir(),
 			{ dist => $self, } );
+	} ## end if ( -e $cpanp_config_location)
+
+	if ( not $self->fragment_exists('CPAN') ) {
+		$self->install_distribution(
+			name             => 'ANDK/CPAN-1.94_52.tar.gz',
+			mod_name         => 'CPAN',
+			makefilepl_param => ['INSTALLDIRS=perl'],
+			buildpl_param    => [ '--installdirs', 'core' ],
+		);
 	}
 
 	return $self;
@@ -327,7 +330,7 @@ unless (%need) {
 	
 END_PERL
 
-	my $cpan_info_file = catfile( $self->output_dir, 'cpan.info' );
+	my $cpan_info_file = catfile( $self->output_dir(), 'cpan.info' );
 	$cpan_string .= <<"END_PERL";
 nstore \\\@toget, '$cpan_info_file';
 print "Completed collecting information on all modules\\n";
@@ -337,7 +340,7 @@ END_PERL
 
 	# Dump the CPAN script to a temp file and execute
 	$self->trace_line( 1, "Running upgrade of all modules\n" );
-	my $cpan_file = catfile( $self->build_dir, 'cpan_string.pl' );
+	my $cpan_file = catfile( $self->build_dir(), 'cpan_string.pl' );
   SCOPE: {
 		my $CPAN_FILE;
 		open $CPAN_FILE, '>', $cpan_file
@@ -347,7 +350,7 @@ END_PERL
 		close $CPAN_FILE
 		  or PDWiX->throw("CPAN script close failed: $OS_ERROR");
 	}
-	$self->_run3( $self->bin_perl, $cpan_file )
+	$self->_run3( $self->bin_perl(), $cpan_file )
 	  or PDWiX->throw('CPAN script execution failed');
 	PDWiX->throw('Failure detected during cpan upgrade, stopping')
 	  if $CHILD_ERROR;
@@ -357,10 +360,10 @@ END_PERL
 
 sub _install_cpan_module {
 	my ( $self, $module, $force ) = @_;
-	$force = $force or $self->force;
-	my $perl_version = $self->perl_version_literal;
-	my $module_id    = $self->_module_fix( $module->id );
-	my $module_file  = substr $module->cpan_file, 5;
+	$force = $force or $self->force();
+	my $perl_version = $self->perl_version_literal();
+	my $module_id    = $self->_module_fix( $module->id() );
+	my $module_file  = substr $module->cpan_file(), 5;
 #<<<
 	my $core =
 	  exists $Module::CoreList::version{ $perl_version }{ $module_id }
@@ -390,18 +393,18 @@ sub _skip_upgrade {
 	my ( $self, $module ) = @_;
 
 	# DON'T try to install Perl.
-	return 1 if $module->cpan_file =~ m{/perl-5 [.]}msx;
+	return 1 if $module->cpan_file() =~ m{/perl-5 [.]}msx;
 
 	# DON'T try to install Term::ReadKey, we
 	# already upgraded it.
-	return 1 if $module->id eq 'Term::ReadKey';
+	return 1 if $module->id() eq 'Term::ReadKey';
 
 	# DON'T try to install Win32API::Registry, we
 	# already upgraded it as far as we can.
-	return 1 if $module->id eq 'Win32API::Registry';
+	return 1 if $module->id() eq 'Win32API::Registry';
 
 	# If the ID is CGI::Carp, there's a bug in the index.
-	return 1 if $module->id eq 'CGI::Carp';
+	return 1 if $module->id() eq 'CGI::Carp';
 
 	# If the ID is ExtUtils::MakeMaker, we've already installed it.
 	# There were some files gotten rid of after 6.50, so
@@ -409,7 +412,7 @@ sub _skip_upgrade {
 	# those files using it.
 
 	# This code is in here for safety as of yet.
-	return 1 if $module->cpan_file =~ m{/ExtUtils-MakeMaker-6 [.] 50}msx;
+	return 1 if $module->cpan_file() =~ m{/ExtUtils-MakeMaker-6 [.] 50}msx;
 
 	return 0;
 } ## end sub _skip_upgrade
@@ -433,7 +436,7 @@ the default tasklist after the "c toolchain" is installed.
 # Just hand off to the larger set of Perl install methods.
 sub install_perl {
 	my $self                = shift;
-	my $install_perl_method = 'install_perl_' . $self->perl_version;
+	my $install_perl_method = 'install_perl_' . $self->perl_version();
 	unless ( $self->can($install_perl_method) ) {
 		PDWiX->throw(
 			"Cannot generate perl, missing $install_perl_method method in "
@@ -442,12 +445,12 @@ sub install_perl {
 	$self->$install_perl_method(@_);
 
 	$self->add_to_fragment( 'perl',
-		[ catfile( $self->image_dir, qw(perl lib perllocal.pod) ) ] );
+		[ $self->_file(qw(perl lib perllocal.pod)) ] );
 
 	return 1;
 } ## end sub install_perl
 
-=head2 install_perl_* (* = 589, 5100, or 5101)
+=head2 install_perl_* (* = git, 589, 5100, or 5101)
 
 	$self->install_perl_5100;
 
@@ -506,10 +509,10 @@ sub install_perl_589 {
 	# fails early if there's a problem
 	$self->trace_line( 1, "Pregenerating toolchain...\n" );
 	my $toolchain = Perl::Dist::WiX::Toolchain->new(
-		perl_version => $self->perl_version_literal,
-		cpan         => $self->cpan->as_string
+		perl_version => $self->perl_version_literal(),
+		cpan         => $self->cpan()->as_string()
 	) or PDWiX->throw('Failed to resolve toolchain modules');
-	unless ( eval { $toolchain->delegate; 1; } ) {
+	unless ( eval { $toolchain->delegate(); 1; } ) {
 		PDWiX::Caught->throw(
 			message => 'Delegation error occured',
 			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
@@ -521,10 +524,10 @@ sub install_perl_589 {
 			info    => $toolchain->get_error() );
 	}
 
-	$self->{toolchain} = $toolchain;
+	$self->_set_toolchain($toolchain);
 
 	# Make the perl directory if it hasn't been made alreafy.
-	$self->make_path( catdir( $self->image_dir, 'perl' ) );
+	$self->make_path( $self->_dir('perl') );
 
 	# Install the main perl distributions
 	$self->install_perl_bin(
@@ -558,17 +561,17 @@ sub install_perl_bin {
 		@_,
 	);
 
-	unless ( $self->bin_make ) {
+	unless ( $self->bin_make() ) {
 		PDWiX->throw('Cannot build Perl yet, no bin_make defined');
 	}
 
 	$perl->install();
 
 	# Should have a perl to use now.
-	$self->{bin_perl} = catfile( $self->image_dir, qw/perl bin perl.exe/ );
+	$self->_set_bin_perl( $self->_file(qw/perl bin perl.exe/) );
 
 	# Add to the environment variables
-	$self->add_env_path( 'perl', 'bin' );
+	$self->add_path( 'perl', 'bin' );
 
 	return 1;
 } ## end sub install_perl_bin
@@ -584,10 +587,10 @@ sub install_perl_5100 {
 	# fails early if there's a problem
 	$self->trace_line( 1, "Pregenerating toolchain...\n" );
 	my $toolchain = Perl::Dist::WiX::Toolchain->new(
-		perl_version => $self->perl_version_literal,
-		cpan         => $self->cpan->as_string
+		perl_version => $self->perl_version_literal(),
+		cpan         => $self->cpan()->as_string()
 	) or PDWiX->throw('Failed to resolve toolchain modules');
-	unless ( eval { $toolchain->delegate; 1; } ) {
+	unless ( eval { $toolchain->delegate(); 1; } ) {
 		PDWiX::Caught->throw(
 			message => 'Delegation error occured',
 			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
@@ -599,10 +602,10 @@ sub install_perl_5100 {
 			info    => $toolchain->get_error() );
 	}
 
-	$self->{toolchain} = $toolchain;
+	$self->_set_toolchain($toolchain);
 
 	# Make the perl directory if it hasn't been made already.
-	$self->make_path( catdir( $self->image_dir, 'perl' ) );
+	$self->make_path( $self->_dir('perl') );
 
 	# Install the main binary
 	$self->install_perl_bin(
@@ -652,10 +655,10 @@ sub install_perl_5101 {
 			info    => $toolchain->get_error() );
 	}
 
-	$self->{toolchain} = $toolchain;
+	$self->_set_toolchain($toolchain);
 
 	# Make the perl directory if it hasn't been made already.
-	$self->make_path( catdir( $self->image_dir, 'perl' ) );
+	$self->_make_path( $self->_dir('perl') );
 
 	# Install the main binary
 	$self->install_perl_bin(
@@ -681,6 +684,59 @@ sub install_perl_5101 {
 	return 1;
 } ## end sub install_perl_5101
 
+sub install_perl_git {
+	my $self = shift;
+
+	# Prefetch and predelegate the toolchain so that it
+	# fails early if there's a problem
+	$self->trace_line( 1, "Pregenerating toolchain...\n" );
+	my $toolchain = Perl::Dist::WiX::Toolchain->new(
+		perl_version => $self->perl_version_literal,
+		cpan         => $self->cpan->as_string
+	) or PDWiX->throw('Failed to resolve toolchain modules');
+	unless ( eval { $toolchain->delegate; 1; } ) {
+		PDWiX::Caught->throw(
+			message => 'Delegation error occured',
+			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
+		);
+	}
+	if ( defined $toolchain->get_error() ) {
+		PDWiX::Caught->throw(
+			message => 'Failed to generate toolchain distributions',
+			info    => $toolchain->get_error() );
+	}
+
+	$self->_set_toolchain($toolchain);
+
+	# Make the perl directory if it hasn't been made already.
+	$self->_make_path( $self->_dir('perl') );
+
+	my $checkout = $self->git_checkout();
+
+	# Install the main binary
+	$self->install_perl_bin(
+		name       => 'perl',
+		url        => URI::file->new($checkout)->as_string(),
+		unpack_to  => 'perl',
+		install_to => 'perl',
+		toolchain  => $toolchain,
+		patch      => [ qw{
+			  lib/CPAN/Config.pm
+			  win32/config.gc
+			  win32/config_sh.PL
+			  win32/config_H.gc
+			  }
+		],
+		license => {
+			'perl-git/Readme'   => 'perl/Readme',
+			'perl-git/Artistic' => 'perl/Artistic',
+			'perl-git/Copying'  => 'perl/Copying',
+		},
+		git => $self->git_describe(),
+	);
+
+	return 1;
+} ## end sub install_perl_git
 
 #####################################################################
 # Perl Toolchain Support
@@ -701,7 +757,7 @@ the default tasklist after the perl interpreter is installed.
 
 sub install_perl_toolchain {
 	my $self      = shift;
-	my $toolchain = $self->toolchain;
+	my $toolchain = $self->_get_toolchain();
 
 	if ( 0 == $toolchain->dist_count() ) {
 		PDWiX->throw('Toolchain did not get collected');
@@ -714,7 +770,7 @@ sub install_perl_toolchain {
 		my $automated_testing = 0;
 		my $release_testing   = 0;
 		my $overwritable      = 0;
-		my $force             = $self->force;
+		my $force             = $self->force();
 		if ( $dist =~ /Scalar-List-Util/msx ) {
 
 			# Does something weird with tainting
@@ -746,6 +802,9 @@ sub install_perl_toolchain {
 		if ( $dist =~ /CPAN-1 [.] 9402/msx ) {
 
 			# 1.9402 fails its tests... ANDK says it's a test bug.
+			# Alias agrees that we include 1.94_51 because of the fix
+			# for the Win32 file:// bug.
+			$dist  = 'ANDK/CPAN-1.94_52.tar.gz';
 			$force = 1;
 		}
 		if ( $dist =~ /ExtUtils-ParseXS-2[.]20(?:02)?[.]tar[.]gz/msx ) {
@@ -760,7 +819,7 @@ sub install_perl_toolchain {
 		}
 		if ( $dist =~ /Module-Build-/msx ) {
 
-			# 0.31 does not include a Makefile.PL.
+			#
 			$dist = 'DAGOLDEN/Module-Build-0.3500_01.tar.gz';
 		}
 		if ( $dist =~ /ExtUtils-MakeMaker-/msx ) {
