@@ -15,19 +15,21 @@ use MooseX::Types::Moose qw( Bool );
 use Params::Util qw( _INSTANCE );
 use File::Spec::Functions qw( abs2rel splitpath catpath catdir splitdir );
 use List::MoreUtils qw( uniq );
+use Digest::CRC qw( crc32_base64 );
 require Perl::Dist::WiX::Exceptions;
-require Perl::Dist::WiX::DirectoryRef;
+require Perl::Dist::WiX::Tag::DirectoryRef;
 require Perl::Dist::WiX::DirectoryCache;
 require Perl::Dist::WiX::DirectoryTree2;
 require WiX3::XML::Component;
 require WiX3::XML::Feature;
+require WiX3::XML::FeatureRef;
 require WiX3::XML::File;
 require WiX3::Exceptions;
 require File::List::Object;
 require Win32::Exe;
 
-our $VERSION = '1.090_102';
-$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+our $VERSION = '1.101_001';
+$VERSION =~ s/_//ms;
 
 extends 'WiX3::XML::Fragment';
 with 'WiX3::Role::Traceable';
@@ -45,6 +47,30 @@ has files => (
 	},
 );
 
+has feature => (
+	is       => 'bare',
+	isa      => 'Maybe[WiX3::XML::Feature]',
+	init_arg => undef,
+	lazy     => 1,
+	reader   => '_get_feature',
+	builder  => '_build_feature',
+);
+
+sub _build_feature {
+	my $self = shift;
+	if ( not $self->in_merge_module() ) {
+		my $feat = WiX3::XML::Feature->new(
+			id      => $self->get_id(),
+			level   => 1,
+			display => 'hidden',
+		);
+		$self->add_child_tag($feat);
+		return $feat;
+	} else {
+		return undef;
+	}
+} ## end sub _build_feature
+
 has can_overwrite => (
 	is      => 'ro',
 	isa     => Bool,
@@ -52,26 +78,11 @@ has can_overwrite => (
 	reader  => 'can_overwrite',
 );
 
-# TODO: Uncomment when we figure out how to get feature tags working right.
-#has feature => (
-#	is       => 'ro',
-#	isa      => 'WiX3::XML::Feature',
-#	init_arg => undef,
-#	lazy     => 1,
-#	reader   => '_get_feature',
-#	builder  => '_build_feature',
-#);
-
-#sub _build_feature {
-#	my $self = shift;
-#	my $feat = WiX3::XML::Feature->new(
-#		id => $self->get_id(),
-#		level => 1,
-#		display => 'hidden',
-#	);
-#	$self->add_child_tag($feat);
-#	return $feat;
-#}
+has in_merge_module => (
+	is      => 'ro',
+	isa     => Bool,
+	default => 0,
+);
 
 # This type of fragment needs regeneration.
 sub regenerate {
@@ -109,8 +120,6 @@ sub _add_file_to_fragment {
 	my ( $volume, $dirs, $file ) = splitpath( $file_path, 0 );
 	my $path_to_find = catdir( $volume, $dirs );
 
-# TODO: Wait until feature tags working right.
-#	my @child_tags = $self->_get_feature()->get_child_tags();
 	my @child_tags       = $self->get_child_tags();
 	my $child_tags_count = scalar @child_tags;
 
@@ -129,8 +138,8 @@ sub _add_file_to_fragment {
 		$i_step1++;
 
 		next STEP1
-		  unless ( $tag_step1->isa('Perl::Dist::WiX::Directory')
-			or $tag_step1->isa('Perl::Dist::WiX::DirectoryRef') );
+		  unless ( $tag_step1->isa('Perl::Dist::WiX::Tag::Directory')
+			or $tag_step1->isa('Perl::Dist::WiX::Tag::DirectoryRef') );
 
 		# Search for directory.
 		$directory_step1 = $tag_step1->search_dir(
@@ -164,15 +173,13 @@ sub _add_file_to_fragment {
 	if ( defined $directory_step2 ) {
 
 		my $directory_ref_step2 =
-		  Perl::Dist::WiX::DirectoryRef->new(
+		  Perl::Dist::WiX::Tag::DirectoryRef->new(
 			directory_object => $directory_step2 );
 
-# TODO: Wait until feature tags work right...
-#		$self->_get_feature()->add_child_tag($directory_ref_step2);
 		$self->add_child_tag($directory_ref_step2);
 		$self->_add_file_component( $directory_ref_step2, $file_path );
 		return ();
-	} ## end if ( defined $directory_step2)
+	}
 
 # Step 3: Search in our own directories non-exactly.
 #  SUCCESS: Create directories, create component and file.
@@ -190,8 +197,8 @@ sub _add_file_to_fragment {
 		$i_step3++;
 
 		next STEP3
-		  unless ( $tag_step3->isa('Perl::Dist::WiX::Directory')
-			or $tag_step3->isa('Perl::Dist::WiX::DirectoryRef') );
+		  unless ( $tag_step3->isa('Perl::Dist::WiX::Tag::Directory')
+			or $tag_step3->isa('Perl::Dist::WiX::Tag::DirectoryRef') );
 
 		# Search for directory.
 		$directory_step3 = $tag_step3->search_dir(
@@ -230,11 +237,9 @@ sub _add_file_to_fragment {
 	if ( defined $directory_step4 ) {
 
 		my $directory_ref_step4 =
-		  Perl::Dist::WiX::DirectoryRef->new(
+		  Perl::Dist::WiX::Tag::DirectoryRef->new(
 			directory_object => $directory_step4 );
 
-# TODO: Wait until feature tags work right.
-#		$self->_get_feature()->add_child_tag($directory_ref_step4);
 		$self->add_child_tag($directory_ref_step4);
 		( $directory_final, @fragment_ids ) =
 		  $self->_add_directory_recursive( $directory_ref_step4,
@@ -284,8 +289,12 @@ sub _add_directory_recursive {
 	}
 
 	foreach my $dir_to_add (@dirs_to_add) {
-		$directory_object =
-		  $directory_object->add_directory( name => $dir_to_add );
+		$directory_object = $directory_object->add_directory(
+			name => $dir_to_add,
+			id   => crc32_base64(
+				catdir( $directory_object->get_path(), $dir_to_add )
+			),
+		);
 		if ( $cache->exists_in_cache($directory_object) ) {
 			$tree->add_directory( $directory_object->get_path() );
 			push @fragment_ids,
@@ -304,7 +313,36 @@ sub _add_file_component {
 	my $tag  = shift;
 	my $file = shift;
 
-	my $component = WiX3::XML::Component->new( path => $file );
+	# We need a shorter ID than a GUID. CRC32's do that.
+	# it does NOT have to be cryptographically perfect,
+	# it just has to TRY and be unique over a set of 10,000
+	# file names and compoments or so.
+
+	my $revext;                        # Reverse the extension.
+	my ( undef, undef, $filename ) = splitpath($file);
+	$filename = reverse scalar $filename;
+	($revext) = $filename =~ m{\A(.*?)[.]}msx;
+	if ( not defined $revext ) {
+		$revext = 'Z';
+	}
+
+	my $component_id = "${revext}_";
+	$component_id .= crc32_base64($file);
+	$component_id =~ s{[+]}{_}ms;
+	$component_id =~ s{/}{-}ms;
+
+	my @feature_param = ();
+
+	if ( defined $self->_get_feature() ) {
+		@feature_param =
+		  ( feature => 'Feat_' . $self->_get_feature()->get_id() );
+	}
+
+	my $component = WiX3::XML::Component->new(
+		path => $file,
+		id   => $component_id,
+		@feature_param
+	);
 	my $file_obj;
 
 	# If the file is a .dll or .exe file, check for a version.
@@ -320,13 +358,13 @@ sub _add_file_component {
 			$language = hex substr $vi->{'cur_trans'}, 0, 4;
 			$file_obj = WiX3::XML::File->new(
 				source          => $file,
-				id              => $component->get_id(),
+				id              => $component_id,
 				defaultlanguage => $language,
 			);
 		} else {
 			$file_obj = WiX3::XML::File->new(
 				source => $file,
-				id     => $component->get_id(),
+				id     => $component_id,
 			);
 		}
 	} else {
@@ -334,7 +372,7 @@ sub _add_file_component {
 		# If the file doesn't exist, it gets caught later.
 		$file_obj = WiX3::XML::File->new(
 			source => $file,
-			id     => $component->get_id(),
+			id     => $component_id,
 		);
 	}
 
@@ -344,6 +382,17 @@ sub _add_file_component {
 	return 1;
 } ## end sub _add_file_component
 
+around 'get_componentref_array' => sub {
+	my $orig = shift;
+	my $self = shift;
+
+	if ( $self->in_merge_module() ) {
+		return $self->$orig();
+	} else {
+		return $self->_get_feature()->get_componentref_array();
+	}
+};
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
